<?php
namespace Planejamento\Logic\Efetivos;

use \Geral\Util\Ambiente;
use \Geral\Util\DateUtil;
use \Geral\Entities\Paramgeral;
use \Faturamento\Entities\Efetclie;
use \Planejamento\Entities\Cardadia;
use \Planejamento\Entities\Compcard;
use \Planejamento\Entities\Paramplaneja;
use \Indeterminado\Entities\Servifat;
use \Indeterminado\Entities\Logaltefet;
use \Planejamento\Repositories\Retirada;
use \Planejamento\Repositories\Itlanctoest;
use \Planejamento\Repositories\Itemretiprat;

class EfetivosPlanejamento
{


    /**
     * Soma a quantidade de comensais para clientes, funcionarios e doacoes em comensais efetivos
     *
     * @static
     * @param integer $qtd_clientes     Qtde de clientes efetivos
     * @param integer $qtd_funcionarios Qtde de funcionarios efetivos
     * @param integer $qtd_doacoes      Qtde de doacoes efetivos
     * @return mixed
     */
    //@todo O campo â€œEfetivoâ€� exibe o somatÃ³rio das quantidades informadas nos trÃªs campos
    public static function somaComensaisEfetivos($qtd_clientes, $qtd_funcionarios, $qtd_doacoes)
    {
        return $qtd_clientes + $qtd_funcionarios + $qtd_doacoes;
    }


    /**
     * Valida se a quantidade informada de efetivos e maior ou igual a zero
     *
     * @static
     * @param  integer $quantidade  Quantidade informada
     * @param  string  $item        Item informado
     * @return string               Mensagem de retorno
     */
    //@todo acao deve ser realizada somente sobre o registro que foi alterado
    //@todo variavel $item sera identificada na camada facade com o nome do campo
    public static function verificaQuantidadeInformada($quantidade, $item)
    {
        if($quantidade < 0){
            switch($item){
                case "CLIENTES":
                    \Planejamento\Logic\Efetivos\Exception\QuantidadeInformada::quantidadeInformadaClientes();
                    break;
                case "FUNCIONARIOS":
                    \Planejamento\Logic\Efetivos\Exception\QuantidadeInformada::quantidadeInformadaFuncionarios();
                    break;
                case "DOACOES":
                    \Planejamento\Logic\Efetivos\Exception\QuantidadeInformada::quantidadeInformadaDoacoes();
                    break;
                case "EFETIVOS":
                    \Planejamento\Logic\Efetivos\Exception\QuantidadeInformada::quantidadeInformadaEfetivos();
                    break;
                case "PRATO":
                    \Planejamento\Logic\Efetivos\Exception\QuantidadeInformada::quantidadeInformadaComensaisPrato();
                    break;
                case "QTD_VENDIDA":
                    \Planejamento\Logic\Efetivos\Exception\QuantidadeInformada::quantidadeVendidaInformadaPrato();
                    break;
            }
        }
    }

    /**
     * Valida permissao para lancar efetivos com data do cardapio superior a data de processamento
     *
     * @static
     * @param integer    $nrorg       Numero da organizacao
     * @param integer    $cdfilial    Codigo da filial
     * @param integer    $dtCardapio  Data do cardapio
     * @return string                 Mensagem de retorno
     */
    //@todo acao deve ser realizada ao tentar editar qualquer informacao de comensal efetivo
    //@todo centralizar consultas da Paramplaneja depois que houver refatoracao no arquivo de Parametros ou Ambiente
    public static function verificaPermissaoLancamentoEfetivosDataSuperior($nrorg, $cdfilial, $dtCardapio)
    {
        $dtCardapio = DateUtil::getDataDeString($dtCardapio);
        $dtProcessamento = DateUtil::getDataDeString(\Estoque\Util\Parametros::getDataProcessamento());

        if (DateUtil::comparaDatas($dtCardapio, $dtProcessamento, DateUtil::DEPOIS)) {
            /** @var $paramPlaneja Paramplaneja */
            $paramPlaneja = Paramplaneja::getObject (
                    array(
                        'nrorg'        => $nrorg,
                        'cdfilial'     => $cdfilial,
                        'cdparplaneja' => 1,
                    )
            );
            $idPermissaoLancamentoDataSuperior = $paramPlaneja->getIdperefeposdtpr();
            if ($idPermissaoLancamentoDataSuperior == Paramplaneja::IDPEREFEPOSDTPR_NAO) {
                \Planejamento\Logic\Efetivos\Exception\RestricoesLancamentoEfetivos::DataCardapioSuperiorDataProcessamento();
            }
        }

    }


    /**
     * Valida permissao para lancar os efetivos sem retirada do planejamento
     * @static
     * @param integer $nrorg              Numero da organizacao
     * @param integer $cdfilial           Codigo da filial
     * @param integer $nrcardapio         Numero do cardapio
     * @param integer $qtdeClientes        Qtde de clientes anterior
     * @param integer $qtdeFuncionarios    Qtde de funcionarios anterior
     * @param integer $qtdeDoacoes         Qtde de doacoes anterior
     */
    //@todo deve ser acionada antes da edicao das informacoes de comensais por cardapio, prato e/ou comensais por cliente.
    public static function verificaPermissaoLancamentoSemRetirada($nrorg, $cdfilial, $nrcardapio, $qtdeClientes,
                                                                  $qtdeFuncionarios, $qtdeDoacoes)
    {
        /** @var $paramPlaneja Paramplaneja */
        $paramPlaneja                     = Paramplaneja::getObject(
            array(
                'nrorg'        => $nrorg,
                'cdfilial'     => $cdfilial,
                'cdparplaneja' => 1,
            )
        );

        if (is_object($paramPlaneja)) {
            $permiteLancamentoSemRetirada = $paramPlaneja->getIdperlefesretpla();

            // Condicao para a clausula "if" abaixo.
            $verificaPermissaoSemRetirada = $permiteLancamentoSemRetirada === Paramplaneja::IDPERLEFESRETPLA_NAO
                && empty($qtdeClientes) && empty($qtdeFuncionarios) && empty($qtdeDoacoes) && empty($nrcardapio) === false;
            if ($verificaPermissaoSemRetirada) {
                $qtdItens = Itlanctoest::QtdRetiradasEvolucaoEstoque($nrorg, $cdfilial, $nrcardapio);
                if ($qtdItens == 0) {
//                if (1 == 0) {
                    // NÃ£o hÃ¡ produto baixado em estoque no dia.
                    \Planejamento\Logic\Efetivos\Exception\RestricoesLancamentoEfetivos::LancamentoSemRetirada();

                }
            }
        }
    }


    /**
     * Verifica se a quantidade informada de comensais do cliente (Efetivos do Planejamento) Ã© igual ao somatÃ³rio de comensais
     * informados por cliente em â€œEfetivos de Faturamentoâ€�. Se houver utilizacao da consistencia sobre o minimo de efetivos,
     * havera bloqueio para o usuario, caso nao utilize a consistencia apenas informa o usuario da diferenÃ§a encontrada de comensais para cliente.
     * @static
     * @param integer $nrorg      Numero da organizacao
     * @param integer $cdfilial   Codigo da filial
     * @param integer $cdservico  Codigo do servico
     * @param integer $nrcardapio Numero do cardapio
     * @param integer $dtefetclie Data do cardapio
     * @return string             Mensagem de retorno
     */
    //@todo deve ser acionada na saÃ­da da tela de Efetivos, na mudanÃ§a de abas (efetivos do planejamento ou efetivos do faturamento) ou atraves do acionamento de uma action destinada a esta finalidade.
    public static function utilizaConsistenciaSobreMinimoEfetivos($nrorg, $cdfilial, $cdservico, $nrcardapio, $dtefetclie)
    {
        $dtefetclie = DateUtil::getDataDeString($dtefetclie, DateUtil::FORMATO_BRASILEIRO_DATAHORA);

        /** @var $paramGeral Paramgeral */
        $paramGeral = Paramgeral::getObjectByWhere("NRORG = ?", array($nrorg));
        $idUtilizaConsistenciaMinEfetivos = $paramGeral->getIdconsminefe();

        /** @var $cardaDia Cardadia */
        $cardaDia = Cardadia::getObjectByWhere("NRORG = ? AND CDFILIAL = ? AND NRCARDAPIO = ?", array($nrorg, $cdfilial, $nrcardapio));
         $validaComensais = tk_get_context_vars('QTCOMEFETCAR', 'pla01000');
        if($validaComensais == null){
            $qtdComensaisClienteEfetivos = 0;
        }else{
            $qtdComensaisClienteEfetivos = $cardaDia->getQtcliefetcar();
        }

        $efetClie = Efetclie::getObjectsByWhere("NRORG = ? AND CDFILIAL = ? AND CDSERVPLAN = ? AND DTEFETCLIE = ?",
            array($nrorg, $cdfilial, $cdservico, $dtefetclie));

        $somaComensaisFaturados = 0;
        $nmclientes = '';
        $nmservico = '';

        /** @var $qtdComensaisCliente Efetclie */
        foreach ($efetClie as $qtdComensaisCliente ) {
            $somaComensaisFaturados += $qtdComensaisCliente->getQtcomefetcli();
            $nmclientes .= $qtdComensaisCliente->getCliente()->getNmrazsocclie().'<br>';
            $nmservico = $qtdComensaisCliente->getServplan()->getNmservico();
        }

        if (!empty($efetClie)) {
            if ($idUtilizaConsistenciaMinEfetivos == 'S') {
                if ($qtdComensaisClienteEfetivos != $somaComensaisFaturados) {
                    //@todo A mensagem supracitada deve bloquear a saida da tela.
                    \Planejamento\Logic\Efetivos\Exception\MinimoEfetivos::utilizaConsistenciaSobreMinimoEfetivos($nmclientes, $nmservico);
                }
            } else {
                if ($qtdComensaisClienteEfetivos != $somaComensaisFaturados) {
                    //@todo Nesse caso, somente exibir uma mensagem informativa.
                    \Planejamento\Logic\Efetivos\Exception\MinimoEfetivos::diferencaComensaisCliente($nmclientes, $nmservico);
                }
            }
        }

    }


    /**
     * Obriga que um cardapio que possui retirada tenha um numero de efetivos superior a zero.
     * @static
     * @param integer $nrorg        Numero da organizacao
     * @param integer $cdfilial     Codigo da filial
     * @param integer $nrcardapio   Numero do cardapio
     * @param integer $funcionarios Quantidade de funcionarios
     * @param integer $doacoes      Quantidade de doacoes
     * @param integer $clientes     Quantidade de clientes
     * @return string               Mensagem de retorno
     */
    //@todo Esta validaÃ§Ã£o deve ser acionada antes da confirmaÃ§Ã£o de alteraÃ§Ãµes realizadas sobre os efetivos do cardÃ¡pio.
    //@todo variaveis $funcionarios, $doacoes, $clientes serao identificadas na camada facade com o nome do field
    public static function validaCardapioComRetirada($nrorg, $cdfilial, $nrcardapio, $funcionarios, $doacoes, $clientes)
    {
        if ($funcionarios == 0 && $doacoes == 0 && $clientes == 0) {
            $retirada = Retirada::QtdRetiradasIndependenteEvolucaoEstoque($nrorg, $cdfilial, $nrcardapio);
            if ($retirada > 0) {
                \Planejamento\Logic\Efetivos\Exception\RestricoesLancamentoEfetivos::CardapioComRetirada();
            }
        }
    }


    /**
     * Valida se o intervalo entre a data do cardapio e a data de processamento da filial ultrapassa a tolerancia de dias
     * estabelecidos para lancamento dos efetivos
     * @static
     * @param integer     $nrorg      Numero da organizacao
     * @param integer     $cdfilial   Codigo da filial
     * @param integer     $dtcardapio Data do cardapio
     * @return string                 Mensagem de retorno
     */
    //@todo deve ser acionada ao tentar editar qualquer informaÃ§Ã£o de comensal efetivo
    //@todo centralizar consultas da Paramplaneja depois que houver refatoracao no arquivo de Parametros ou Ambiente
    public static function utilizaBloqueioEfetivosParaDiasFechados($nrorg, $cdfilial, $dtcardapio)
    {
        $dtcardapio = new \TkDateTime($dtcardapio);
        /** @var $paramPlaneja Paramplaneja */
        $paramPlaneja = Paramplaneja::getObject(
            array(
                'nrorg'        => $nrorg,
                'cdfilial'     => $cdfilial,
                'cdparplaneja' => 1
            )
        );
        $idBloqueiaAlteracaoDiasFechados = $paramPlaneja->getIdblqefediafech();

        if ($idBloqueiaAlteracaoDiasFechados == Paramplaneja::IDBLQEFEDIAFECH_SIM){
            $dtProcessamento = new \TkDateTime(\Estoque\Util\Parametros::getDataProcessamento(), \TkDateTime::FORMAT_DATE);
            $intervalo_dias = count($dtProcessamento->intervalToArray($dtcardapio, \TkDateTime::INTERVAL_DAYS));
            $nrDiasAnterioresDtProc = $paramPlaneja->getNrdiaantdtproc();
            if ($intervalo_dias > $nrDiasAnterioresDtProc) {
                \Planejamento\Logic\Efetivos\Exception\RestricoesLancamentoEfetivos::BloqueioDiasFechados($nrDiasAnterioresDtProc);
            }
        }
    }


    /**
     * Transacao acionada ao atualizar os comensais efetivos
     * @static
     * @param integer     $nrorg               Numero da organizacao
     * @param integer     $cdfilial            Codigo da filial
     * @param integer     $cdservico           Codigo do servico
     * @param integer     $nrcardapio          Numero do cardapio
     * @param integer     $dtcardapio          Data do cardapio
     * @param integer     $qtd_comensais_ant   Quantidade de comensais anterior
     * @param integer     $qtd_comensais_atual Quantidade de comensais atual
     * @param integer     $operador            Codigo do operador
     * @throws \Exception
     */
    //@todo deve ser acionado ao atualizar a quantidade de comensais efetivos em Efetivos do Planejamento
    public static function atualizaEfetivosPlanejamento(
        $nrorg, $cdfilial, $cdservico, $nrcardapio, $dtcardapio, $qtd_comensais_ant, $qtd_comensais_atual, $operador
    )
    {
        try {
            \Setforms2\Shared\Registry::getEntityManager()->beginTransaction();
            self::atualizaQtdComensaisPorPrato($nrorg, $cdfilial, $nrcardapio, $qtd_comensais_atual);
            self::atualizaQtdProduzidaPorPrato($nrorg, $cdfilial, $nrcardapio);
            self::insereLogAlteracaoEfetivos($nrorg, $cdfilial, $cdservico, $dtcardapio, $qtd_comensais_ant, $qtd_comensais_atual, $operador);
            \Setforms2\Shared\Registry::getEntityManager()->flush();
            \Setforms2\Shared\Registry::getEntityManager()->commit();
        } catch (\Exception $e) {
            \Setforms2\Shared\Registry::getEntityManager()->rollback();
            throw $e;
        }
    }


    /**
     * Transacao acionada ao atualizar os clientes efetivos
     *
     * @static
     * @param integer     $nrorg               Numero da organizacao
     * @param integer     $cdfilial            Codigo da filial
     * @param integer     $cdservico           Codigo do servico
     * @param integer     $dtcardapio          Data do cardapio
     * @param integer     $qtcomeefetclie      Qtde de comensais do cliente
     * @throws \Exception
     */
    //@todo deve ser acionado ao atualizar a quantidade de comensais efetivos do cliente em Efetivos do Planejamento
    public static function atualizaClientesEfetivosFaturamento($nrorg, $cdfilial, $cdservico, $dtcardapio, $qtcomeefetclie)
    {
        try {
            /** @var $servicoFaturado Servifat */
            $servicoFaturado = Servifat::getObjectByWhere("NRORG = ? AND CDFILIAL = ? AND NVL(CDSERVICFATURAM, CDSERVFILI) = ?",
                                                            array($nrorg, $cdfilial, $cdservico));
            $clienteFaturado = \Planejamento\Repositories\Efetclie::ClienteEfetivosFaturamento($nrorg, $cdfilial, $cdservico, $dtcardapio);
            if (is_object($servicoFaturado) && count($clienteFaturado) == 1) {
                \Setforms2\Shared\Registry::getEntityManager()->beginTransaction();
                /** @var $efetClie Efetclie */
                $efetClie = Efetclie::getObjectByWhere("NRORG = ? AND CDFILIAL = ? AND CDSERVFILI = ? AND DTEFETCLIE = ? AND CDCLIENTE = ? AND CDSERVPLAN = ?",
                                                        array($nrorg, $cdfilial, $cdservico, $dtcardapio, $clienteFaturado[0]['CDCLIENTE'], $cdservico));
                if (is_object($efetClie)) {
                    $efetClie->getQtcomefetcli($qtcomeefetclie);
                } else {
                    $efetClie = new Efetclie();
                    /** @var $Cliente \Geral\Entities\Base\Cliente */
                    $Cliente = \Geral\Entities\Base\Cliente::getObjectByWhere("NRORG = ? AND CDCLIENTE = ?", array($nrorg, $clienteFaturado[0]['CDCLIENTE']));
                    $servfat = ($servicoFaturado->getServicfaturam()->getCdservfili()) ?
                        $servicoFaturado->getServicfaturam()->getCdservfili() : $servicoFaturado->getServfili()->getCdservfili();
                    /** @var $Servico \Geral\Entities\Base\Servico */
                    $Servico = \Geral\Entities\Base\Servico::getObjectByWhere("NRORG = ? AND CDFILIAL = ? AND CDSERVFILI = ?", array($nrorg, $cdfilial, $servfat));
                    /** @var $ServicoPlan \Geral\Entities\Base\Servico */
                    $ServicoPlan = \Geral\Entities\Base\Servico::getObjectByWhere("NRORG = ? AND CDFILIAL = ? AND CDSERVFILI = ?", array($nrorg, $cdfilial, $cdservico));
                    $efetClie->setCdfilial($cdfilial);
                    $efetClie->setServfili($Servico);
                    $efetClie->setDtefetclie(\Geral\Util\DateUtil::getDataDeString($dtcardapio));
                    $efetClie->setCliente($Cliente);
                    $efetClie->setServplan($ServicoPlan);
                    $efetClie->setQtcomefetcli($qtcomeefetclie);
                    $efetClie->setVrservfatuefcli(null);
                    $efetClie->setQtvendaefetcli(null);
                }
                $efetClie->persist();
                \Setforms2\Shared\Registry::getEntityManager()->flush();
                \Setforms2\Shared\Registry::getEntityManager()->commit();
            }
        } catch (\Exception $e) {
            \Setforms2\Shared\Registry::getEntityManager()->rollback();
            throw $e;
        }
    }


    /**
     * Atualiza qtde de comensais por prato
     * @static
     * @param integer     $nrorg          Numero da organizacao
     * @param integer     $cdfilial       Codigo da filial
     * @param integer     $nrcardapio     Numero do cardapio
     * @param integer     $qtd_comensais  Quantidade de comensais
     */
    private static function atualizaQtdComensaisPorPrato($nrorg, $cdfilial, $nrcardapio, $qtd_comensais)
    {
        $compCard = Compcard::getObjectsByWhere("NRORG = ? AND CDFILIAL = ? AND NRCARDAPIO = ?", array($nrorg, $cdfilial, $nrcardapio));
        /** @var $prato Compcard */
        foreach ($compCard as $prato) {
            $perc_consumo = ($qtd_comensais * $prato->getVrpeconscard())/100;
            $prato->setQtcomefetpra($perc_consumo);
            $prato->persist();
        }
    }


    /**
     * Atualiza qtde produzida por prato
     * @static
     * @param integer     $nrorg          Numero da organizacao
     * @param integer     $cdfilial       Codigo da filial
     * @param integer     $nrcardapio     Numero do cardapio
     */
    private static function atualizaQtdProduzidaPorPrato($nrorg, $cdfilial, $nrcardapio)
    {
        $pratos = Itemretiprat::QtdProduzidaPorPrato($nrorg, $cdfilial, $nrcardapio);
        foreach ($pratos as $prato){
            /** @var $compCard Compcard */
            $compCard = Compcard::getObject(array('nrorg' => $nrorg, 'cdfilial' => $cdfilial, 'nrcardapio' => $nrcardapio,
            'cdtipoprat' => $prato['CDTIPOPRAT'], 'cdfilauxprat' => $prato['CDFILAUXPRAT'], 'cdprato' => $prato['CDPRATO']));
            $compCard->setQtproduzprat($prato['QTPRODUZIDA']);
            $compCard->persist();
        }
    }


    /**                                                            ]
     * Insere log de alteracao dos efetivos
     * @static
     * @param integer     $nrorg              Numero da organizacao
     * @param integer     $cdfilial           Codigo da filial
     * @param integer     $cdservico          Codigo do servico
     * @param integer     $dtcardapio         Data do cardapio
     * @param integer     $qtd_efetivos_ant   Qtd de efetivos anterior
     * @param integer     $qtd_efetivos_atual Qtd de efetivos atual
     */
    private static function insereLogAlteracaoEfetivos($nrorg, $cdfilial, $cdservico, $dtcardapio, $qtd_efetivos_ant, $qtd_efetivos_atual, $operador)
    {

        $dtcardapio      = DateUtil::getDataDeString($dtcardapio);
        $dtProcessamento = DateUtil::getDataAtual();
        if (DateUtil::comparaDatas($dtcardapio, $dtProcessamento, DateUtil::ANTES) && $qtd_efetivos_ant != null) {
            /** @var $logAltEfet Logaltefet */
            $logAltEfet = new Logaltefet();
            $logAltEfet->setNrorg($nrorg);
            $logAltEfet->setCdfilial($cdfilial);
            $logAltEfet->setCdservfili($cdservico);
            $logAltEfet->setDtlogaltefet(DateUtil::getDataAtual());
            $logAltEfet->setQtefetant($qtd_efetivos_ant);
            $logAltEfet->setQtefetatual($qtd_efetivos_atual);
            $logAltEfet->setCdoperador($operador);
            $logAltEfet->setIdatualrop('N');
            $logAltEfet->setDtaltefetivo($dtcardapio);
            $logAltEfet->persist();
        }

    }


    public static function insereEfetivosPlanejamento($cdfilial, $nrcardapio, $nrorg, $refeicoesCliente, $funcionariosEfetivos, $doacoesEfetivas, $comensaisEfetivos, $dtultatu, $cdoperultatu){

        try{
            /** @var $cardadia Cardadia */
            $cardadia = Cardadia::getObjectByWhere(
                "CDFILIAL = ? AND NRCARDAPIO = ? AND NRORG = ?",
                array($cdfilial, $nrcardapio, $nrorg)
            );

            if($refeicoesCliente >= 0 && $funcionariosEfetivos >= 0 && $doacoesEfetivas >= 0){
                $cardadia->atualizaEfetivosPLanejamnto($refeicoesCliente, $funcionariosEfetivos, $doacoesEfetivas, $comensaisEfetivos, $dtultatu, $cdoperultatu, $nrorg);
                \Setforms2\Shared\Registry::getEntityManager()->flush();
            } else{
                tk_warning(tk_get_message_by_name("msg_quantidade_maior_zero"));
            }
        } catch (\Exception $e) {
            \Setforms2\Shared\Registry::getEntityManager()->rollback();
            throw $e;
        }

    }

     // Created by marcelomoura

    public static function ajustaComensaisPrato($totalEfetivos, $cdfilial, $nrcard){        
        $connection = \Setforms2\Shared\Registry::getEntityManager();
        $connection->beginTransaction();
            try{

                 /** @var $pratos Compcard */
                $pratos = Compcard::getObjectsByWhere(
                        "CDFILIAL = ?  AND
                        NRCARDAPIO = ?",
                        array($cdfilial, $nrcard)
                );

            /** @var $prato Compcard */
            foreach ($pratos as $prato) {
                $vrpeconscard = $prato->getVrpeconscard();

                //Calculo para o ajuste dos comensais
                $comensaisAjustados = (($totalEfetivos * $vrpeconscard) / 100);

                //Seta o novo valor dos comensais no banco de dados
                $prato->setQtcomefetpra($comensaisAjustados);
                $prato->persist();
            }
                $connection->flush();
                $connection->commit();
            } catch (\Exception $e) {
                tk_warning($e->getMessage());
                $connection->rollback();
            }

    }

     // Created by marcelomoura

    public static function confirmaRateioEfetivos($cdfilial, $cdservfili, $dtinicio, $dtfinal, $totalEfetivos, $cdCliente, $efetCli){

        $connection = \Setforms2\Shared\Registry::getEntityManager();
        $connection->beginTransaction();
            try{

                 /** @var $efetivos Efetclie */
                $efetivos = Efetclie::getObjectsByWhere(
                        "CDFILIAL = ?  AND
                        CDSERVFILI = ? AND
                        DTEFETCLIE BETWEEN ? AND ?",
                        array($cdfilial, $cdservfili, $dtinicio, $dtfinal)
                );

                /** @var $efetivo Efetclie */
                    foreach ($efetivos as $efetivo) {
                        $data = $efetivo->getDtefetclie();
                        $cdclie = $efetivo->getCdcliente();

                           if($cdclie == $cdCliente){
                           /** @var $cardapios Cardadia */
                            $cardapios = Cardadia::getObjectsByWhere(
                                    "CDFILIAL = ?  AND
                                    CDSERVFILI = ? AND
                                    DTCARDAPIO = ? AND
                                    QTCOMEFETCAR <> ?",
                                    array($cdfilial, $cdservfili, $data, 0)
                            );

                            /** @var $cardapio Cardadia */
                            foreach ($cardapios as $cardapio) {
                                $qtcliefetcar = $cardapio->getQtcliefetcar();
                                $efetFat = ROUND((($qtcliefetcar /$totalEfetivos)*$efetCli));
                                $efetivo->setQtcomefetcli($efetFat);
                                $efetivo->persist();
                            }
                        }
                    }

                $connection->flush();
                $connection->commit();
            } catch (\Exception $e) {
                tk_warning($e->getMessage());
                $connection->rollback();
            }

    }

}