<?php
/**
 * Namespace Tecfood\Integracao\Services
 *
 * PHP version 5
 *
 * @category Php
 * @package  Tecfood\Integracao\Services
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Teknisa\Logic\IntNutrientes\Services;
use Geral\Entities\Nutriente;
use Geral\Util\DateUtil;
use Planejamento\Entities\Grupnutr;
use Setforms2\Shared\ORM\DateTime;

/**
 * Class EnviaNutrientes para o Cliente
 *
 * PHP version 5
 *
 * @category Php
 * @package  Teknisa\Logic\IntNutrientes\Services
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class EnviaNutrientes
{

    /**
     * Envia os Nutrientes para a base do Cliente
     *
     * @param String $nrorg Organização
     *
     * @return array|mixed|null|string.
     */
    public static function enviaNutrientes($nrorg)
    {
        //Define a Data Atual
        $dataAtual  = now();
        if ($dataAtual instanceof DateTime) {
            $dataAtual = DateUtil::truncateData($dataAtual);
        } else {
            $dataAtual = explode(' ', $dataAtual);
            $dataAtual = $dataAtual[0];
            $dataAtual = DateUtil::getDataDeString($dataAtual);
        }

        $json  = array();
        $json['NUTRIENTE'] = array();
        $json['GRUPNUTR']  = array();

        $nutrs = Nutriente::getObjectsByWhere("NRORG = ?", array($nrorg));
        //
        if (empty($nutrs) === false) {
            $i = 0;
            //Insere os Nutrientes no JSON
            foreach ($nutrs as $nutr) {
                if ($nutr instanceof Nutriente) {
                    $json['NUTRIENTE'][$i]['CDNUTRIENTE']    = $nutr->getCdnutriente();
                    $json['NUTRIENTE'][$i]['NMNUTRIENTE']    = $nutr->getNmnutriente();
                    $json['NUTRIENTE'][$i]['NMREDUZIDO']     = $nutr->getNmreduzido();
                    $json['NUTRIENTE'][$i]['IDTIPONUTR']     = $nutr->getIdtiponutr();
                    $json['NUTRIENTE'][$i]['SGUNIDADE']      = $nutr->getSgunidade();
                    $json['NUTRIENTE'][$i]['CDGRUPNUTR']     = $nutr->getCdgrupnutr();
                    $json['NUTRIENTE'][$i]['IDCALORIAS']     = $nutr->getIdcalorias();
                    $json['NUTRIENTE'][$i]['IDNUTRRELEV']    = $nutr->getIdnutrrelev();
                    $json['NUTRIENTE'][$i]['VRFATORNUTR']    = $nutr->getVrfatornutr();
                    $json['NUTRIENTE'][$i]['NRORDEMNUTR']    = $nutr->getNrordemnutr();
                    $json['NUTRIENTE'][$i]['IDKCAL']         = $nutr->getIdkcal();
                    $json['NUTRIENTE'][$i]['NRORG']          = $nutr->getNrorg();
                    $json['NUTRIENTE'][$i]['NRORGINCLUSAO']  = $nutr->getNrorginclusao();
                    $json['NUTRIENTE'][$i]['NRORGULTATU']    = $nutr->getNrorgultatu();
                    $json['NUTRIENTE'][$i]['CDOPERINCLUSAO'] = $nutr->getCdoperinclusao();
                    $json['NUTRIENTE'][$i]['CDOPERULTATU']   = $nutr->getCdoperultatu();
                    $json['NUTRIENTE'][$i]['IDATIVO']        = $nutr->getIdativo();
                    $json['NUTRIENTE'][$i]['DTULTATUNUTR']   = $dataAtual;
                    $json['NUTRIENTE'][$i]['DTINCLUSAO']     = $dataAtual;
                    $json['NUTRIENTE'][$i]['DTULTATU']       = $dataAtual;
                    //
                    $i++;
                }
            }
        }

        $grupnutrs = Grupnutr::getObjectsByWhere("NRORG = ?", array($nrorg));
        //
        if (empty($grupnutrs) === false) {
            $i = 0;
            //Insere os Grupo de Nutrientes no JSON
            foreach ($grupnutrs as $grupnutr) {
                if ($grupnutr instanceof Grupnutr) {
                    $json['GRUPNUTR'][$i]['CDGRUPNUTR']     = $grupnutr->getCdgrupnutr();
                    $json['GRUPNUTR'][$i]['NMGRUPNUTR']     = $grupnutr->getNmgrupnutr();
                    $json['GRUPNUTR'][$i]['NRORG']          = $grupnutr->getNrorg();
                    $json['GRUPNUTR'][$i]['NRORGINCLUSAO']  = $grupnutr->getNrorginclusao();
                    $json['GRUPNUTR'][$i]['NRORGULTATU']    = $grupnutr->getNrorgultatu();
                    $json['GRUPNUTR'][$i]['CDOPERINCLUSAO'] = $grupnutr->getCdoperinclusao();
                    $json['GRUPNUTR'][$i]['CDOPERULTATU']   = $grupnutr->getCdoperultatu();
                    $json['GRUPNUTR'][$i]['DTULTATUGRNU']   = $grupnutr->getDtultatugrnu();
                    $json['GRUPNUTR'][$i]['DTINCLUSAO']     = $dataAtual;
                    $json['GRUPNUTR'][$i]['DTULTATU']       = $dataAtual;
                    //
                    $i++;
                }
            }
        }

        if (empty($json) === false) {
            $json = json_encode($json);
            return $json;
        } else {
            //return array('msg_ger07600_parametroIncorreto', array());
            return tk_get_message_by_name('msg_ger07600_parametroIncorreto');
        }
    }

} 